/**
 * @author [Vijayaprathap Kumar] (vpkumar@nuskin.com)
 * NsAutocomplete.stories.tsx
 * @description NsAutocomplete component.
 */

import React, { useState } from 'react';
import type { StoryObj, Meta } from '@storybook/react';

import { withCenterDecorator } from '@/stories/decorators/withCenterDecorator';
import { NsAutocomplete } from './';
import { AutocompleteMockList } from './mock/MockData';
import { OptionUiComponent } from './mock/MockUI';
import { NsAutocompleteProps, OptionsProps } from './types.d';
import { NsIcon } from '../icon';
import { IconButton } from '@mui/material';

type ComponentType = typeof NsAutocomplete;
type Story = StoryObj<ComponentType>;
type MetaStory = Meta<ComponentType>;

export default {
    title: 'Components/NsAutocomplete',
    component: NsAutocomplete,
    decorators: [withCenterDecorator],
    argTypes: {
        children: {
            control: 'text',
        },
    },
    args: {
        options: AutocompleteMockList,
        seeMore: {
            text: 'See More Results',
            show: true,
            onSeeMore: () => {
                throw new Error('Function not implemented.');
            },
        },
        clear: {
            text: 'Clear Recent Searches',
            show: true,
            onClear: () => {
                throw new Error('Function not implemented.');
            },
        },
        iconStart: <NsIcon name="search" />,
        iconEnd: <NsIcon name="close" size="small" />,
        placeholder: 'search',
    },
} as MetaStory;

const RenderAutocomplete = (args: NsAutocompleteProps) => {
    const [selectedOption, setSelectedOption] = useState<string | OptionsProps | null>(null);
    const [searchTerms, setSearchTerms] = useState<string>('');

    const onSelect = (value: string | OptionsProps | null) => {
        setSelectedOption(value);
        setSearchTerms((value = ''));
    };

    const handleInputChange = (newValue: string) => {
        setSearchTerms(newValue);
    };

    const onInputClear = () => {
        setSelectedOption(null);
        setSearchTerms('');
    };

    return (
        <div>
            <NsAutocomplete
                {...args}
                onChange={handleInputChange}
                onSelect={onSelect}
                renderOptions={OptionUiComponent}
                iconEnd={
                    <IconButton onClick={onInputClear}>
                        <NsIcon name="close" size="small" />
                    </IconButton>
                }
                value={selectedOption}
                inputValue={searchTerms}
            />
        </div>
    );
};

export const Autocomplete: Story = {
    render: RenderAutocomplete,
};
